==> plurall-component-icons-1.0.4.tgz: package/es/Smile.js <==
var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

import _JSXStyle from 'styled-jsx/style';

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from 'react';
import PropTypes from 'prop-types';

var Smile = function (_React$PureComponent) {
  _inherits(Smile, _React$PureComponent);

  function Smile() {
    _classCallCheck(this, Smile);

    return _possibleConstructorReturn(this, (Smile.__proto__ || Object.getPrototypeOf(Smile)).apply(this, arguments));
  }

  _createClass(Smile, [{
    key: 'render',
    value: function render() {
      var _props = this.props,
          color = _props.color,
          viewBox = _props.viewBox;

      return React.createElement(
        'svg',
        { xmlns: 'http://www.w3.org/2000/svg', width: '64', height: '64', viewBox: viewBox, 'data-jsx': 2198366705
        },
        React.createElement(
          'g',
          { fill: color, 'data-jsx': 2198366705
          },
          React.createElement('path', { d: 'M25.494 32c-4.07.06-7.42-3.454-7.494-7.862 0-1.18.884-2.138 1.974-2.138 1.09 0 1.974.957 1.974 2.138 0 2.124 1.59 3.846 3.552 3.846s3.552-1.722 3.552-3.846c0-1.18.884-2.138 1.974-2.138 1.09 0 1.974.957 1.974 2.138-.073 4.408-3.424 7.922-7.494 7.861M31.003 20a2.018 2.018 0 0 1-1.418-.59A1.983 1.983 0 0 1 29 17.996a2.001 2.001 0 0 1 4 0c0 .534-.211 1.043-.585 1.412-.38.377-.885.588-1.412.591M20.003 20a2.018 2.018 0 0 1-1.418-.591A1.985 1.985 0 0 1 18 17.996c0-.533.211-1.043.585-1.412a2.006 2.006 0 0 1 2.83 0c.374.369.585.879.585 1.412 0 .534-.211 1.044-.585 1.413-.38.377-.885.588-1.412.591', 'data-jsx': 2198366705
          })
        ),
        React.createElement(_JSXStyle, {
          styleId: 2198366705,
          css: 'svg[data-jsx="2198366705"]{cursor:pointer}'
        })
      );
    }
  }]);

  return Smile;
}(React.PureComponent);

Smile.defaultProps = {
  color: '#FFFFFF',
  viewBox: '0 0 64 64'
};

Smile.propTypes = {
  color: PropTypes.string,
  viewBox: PropTypes.string
};

export default Smile;

==> plurall-component-icons-1.0.5.tgz: package/es/Smile.js <==
var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from 'react';
import PropTypes from 'prop-types';

var Smile = function (_React$PureComponent) {
  _inherits(Smile, _React$PureComponent);

  function Smile() {
    _classCallCheck(this, Smile);

    return _possibleConstructorReturn(this, (Smile.__proto__ || Object.getPrototypeOf(Smile)).apply(this, arguments));
  }

  _createClass(Smile, [{
    key: 'render',
    value: function render() {
      var _props = this.props,
          color = _props.color,
          viewBox = _props.viewBox;

      return React.createElement(
        'svg',
        { xmlns: 'http://www.w3.org/2000/svg', width: '64', height: '64', viewBox: viewBox },
        React.createElement(
          'g',
          { fill: color },
          React.createElement('path', { d: 'M25.494 32c-4.07.06-7.42-3.454-7.494-7.862 0-1.18.884-2.138 1.974-2.138 1.09 0 1.974.957 1.974 2.138 0 2.124 1.59 3.846 3.552 3.846s3.552-1.722 3.552-3.846c0-1.18.884-2.138 1.974-2.138 1.09 0 1.974.957 1.974 2.138-.073 4.408-3.424 7.922-7.494 7.861M31.003 20a2.018 2.018 0 0 1-1.418-.59A1.983 1.983 0 0 1 29 17.996a2.001 2.001 0 0 1 4 0c0 .534-.211 1.043-.585 1.412-.38.377-.885.588-1.412.591M20.003 20a2.018 2.018 0 0 1-1.418-.591A1.985 1.985 0 0 1 18 17.996c0-.533.211-1.043.585-1.412a2.006 2.006 0 0 1 2.83 0c.374.369.585.879.585 1.412 0 .534-.211 1.044-.585 1.413-.38.377-.885.588-1.412.591' })
        )
      );
    }
  }]);

  return Smile;
}(React.PureComponent);

Smile.defaultProps = {
  color: '#FFFFFF',
  viewBox: '0 0 64 64'
};

Smile.propTypes = {
  color: PropTypes.string,
  viewBox: PropTypes.string
};

export default Smile;
